dart_ipc library

Classes

DartIpcUnix

Functions

bind(String path) Future<ServerSocket>
Binds to a server socket at the specified path, In windows, path should be in the format of \\.\pipe\dart_ipc, In unix, path should be a file path e.g. /tmp/dart_ipc.unix.
connect(String path) Future<Socket>
Connects to a server socket at the specified path, In windows, path should be in the format of \\.\pipe\dart_ipc, In unix, path should be a file path e.g. /tmp/dart_ipc.unix.